@@ -5,9 +5,10 @@
 
     :license: MIT, see LICENSE for more details.
 """
-VERSION = 'v3.3.0'
+VERSION = 'v5.9.4'
 API_PUBLIC_ENDPOINT = 'https://api.softlayer.com/xmlrpc/v3.1/'
 API_PRIVATE_ENDPOINT = 'https://api.service.softlayer.com/xmlrpc/v3.1/'
 API_PUBLIC_ENDPOINT_REST = 'https://api.softlayer.com/rest/v3.1/'
 API_PRIVATE_ENDPOINT_REST = 'https://api.service.softlayer.com/rest/v3.1/'
-USER_AGENT = "SoftLayer Python %s" % VERSION
+USER_AGENT = "softlayer-python/%s" % VERSION
+CONFIG_FILE = "~/.softlayer"
