@@ -4,11 +4,12 @@
 
     :license: MIT, see LICENSE for more details.
 """
-from SoftLayer import exceptions
+from SoftLayer.CLI import exceptions
+from SoftLayer import SoftLayerError
 from SoftLayer import testing
 
 import json
-import mock
+from unittest import mock as mock
 
 
 class FileTests(testing.TestCase):
@@ -50,10 +51,18 @@ class FileTests(testing.TestCase):
                 'username': 'user',
                 'active_transactions': None,
                 'mount_addr': '127.0.0.1:/TEST',
+                'notes': None,
                 'rep_partner_count': None
             }],
             json.loads(result.output))
 
+    def test_volume_list_order(self):
+        result = self.run_command(['file', 'volume-list', '--order=1234567'])
+
+        self.assert_no_fail(result)
+        json_result = json.loads(result.output)
+        self.assertEqual(json_result[0]['id'], 1)
+
     @mock.patch('SoftLayer.FileStorageManager.list_file_volumes')
     def test_volume_count(self, list_mock):
         list_mock.return_value = [
@@ -118,7 +127,7 @@ class FileTests(testing.TestCase):
         result = self.run_command([
             '--really', 'file', 'volume-cancel', '1234'])
 
-        self.assertIsInstance(result.exception, exceptions.SoftLayerError)
+        self.assertIsInstance(result.exception, SoftLayerError)
 
     def test_volume_detail(self):
         result = self.run_command(['file', 'volume-detail', '1234'])
@@ -137,6 +146,7 @@ class FileTests(testing.TestCase):
             'Data Center': 'dal05',
             'Type': 'ENDURANCE',
             'ID': 100,
+            'Notes': "{'status': 'available'}",
             '# of Active Transactions': '1',
             'Ongoing Transaction': 'This is a buffer time in which the customer may cancel the server',
             'Replicant Count': '1',
@@ -221,7 +231,9 @@ class FileTests(testing.TestCase):
                          'Order #478 placed successfully!\n'
                          ' > Performance Storage\n > File Storage\n'
                          ' > 0.25 IOPS per GB\n > 20 GB Storage Space\n'
-                         ' > 10 GB Storage Space (Snapshot Space)\n')
+                         ' > 10 GB Storage Space (Snapshot Space)\n'
+                         '\nYou may run "slcli file volume-list --order 478" to find this file volume after it is '
+                         'ready.\n')
 
     def test_volume_order_endurance_tier_not_given(self):
         result = self.run_command(['file', 'volume-order',
@@ -254,7 +266,9 @@ class FileTests(testing.TestCase):
                          'Order #478 placed successfully!\n'
                          ' > Endurance Storage\n > File Storage\n'
                          ' > 0.25 IOPS per GB\n > 20 GB Storage Space\n'
-                         ' > 10 GB Storage Space (Snapshot Space)\n')
+                         ' > 10 GB Storage Space (Snapshot Space)\n'
+                         '\nYou may run "slcli file volume-list --order 478" to find this file volume after it is '
+                         'ready.\n')
 
     @mock.patch('SoftLayer.FileStorageManager.order_file_volume')
     def test_volume_order_order_not_placed(self, order_mock):
@@ -305,7 +319,9 @@ class FileTests(testing.TestCase):
                          ' > File Storage\n'
                          ' > 20 GB Storage Space\n'
                          ' > 0.25 IOPS per GB\n'
-                         ' > 10 GB Storage Space (Snapshot Space)\n')
+                         ' > 10 GB Storage Space (Snapshot Space)\n'
+                         '\nYou may run "slcli file volume-list --order 479" to find this file volume after it is '
+                         'ready.\n')
 
     @mock.patch('SoftLayer.FileStorageManager.order_file_volume')
     def test_volume_order_performance_manager_error(self, order_mock):
@@ -478,6 +494,26 @@ class FileTests(testing.TestCase):
         self.assertEqual('Failover operation could not be initiated.\n',
                          result.output)
 
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    @mock.patch('SoftLayer.FileStorageManager.disaster_recovery_failover_to_replicant')
+    def test_disaster_recovery_failover(self, disaster_recovery_failover_mock, confirm_mock):
+        confirm_mock.return_value = True
+        disaster_recovery_failover_mock.return_value = True
+        result = self.run_command(['file', 'disaster-recovery-failover', '12345678', '--replicant-id=5678'])
+
+        self.assert_no_fail(result)
+        self.assertIn('Disaster Recovery Failover to replicant is now in progress.\n', result.output)
+
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_disaster_recovery_failover_aborted(self, confirm_mock):
+        confirm_mock.return_value = False
+
+        result = self.run_command(['file', 'disaster-recovery-failover', '12345678',
+                                   '--replicant-id=5678'])
+
+        self.assertEqual(result.exit_code, 2)
+        self.assertIsInstance(result.exception, exceptions.CLIAbort)
+
     def test_replicant_failback(self):
         result = self.run_command(['file', 'replica-failback', '12345678'])
 
@@ -696,7 +732,7 @@ class FileTests(testing.TestCase):
         result = self.run_command(['file', 'volume-limits'])
         self.assert_no_fail(result)
 
-    def test_dep_dupe_refresh(self):
+    def test_dupe_refresh(self):
         result = self.run_command(['file', 'volume-refresh', '102', '103'])
 
         self.assert_no_fail(result)
@@ -705,3 +741,21 @@ class FileTests(testing.TestCase):
         result = self.run_command(['file', 'volume-convert', '102'])
 
         self.assert_no_fail(result)
+
+    @mock.patch('SoftLayer.FileStorageManager.volume_set_note')
+    def test_volume_set_note(self, set_note):
+        set_note.return_value = True
+
+        result = self.run_command(['file', 'volume-set-note', '102', '--note=testing'])
+
+        self.assert_no_fail(result)
+        self.assertIn("successfully!", result.output)
+
+    @mock.patch('SoftLayer.FileStorageManager.volume_set_note')
+    def test_volume_not_set_note(self, set_note):
+        set_note.return_value = False
+
+        result = self.run_command(['file', 'volume-set-note', '102', '--note=testing'])
+
+        self.assert_no_fail(result)
+        self.assertIn("Note could not be set!", result.output)
