@@ -4,9 +4,10 @@
 
     :license: MIT, see LICENSE for more details.
 """
-import mock
+
 import sys
 import tempfile
+from unittest import mock as mock
 
 from SoftLayer.fixtures import SoftLayer_Product_Package as SoftLayer_Product_Package
 from SoftLayer import testing
@@ -93,6 +94,49 @@ class VirtCreateTests(testing.TestCase):
 
         self.assert_called_with('SoftLayer_Virtual_Guest', 'generateOrderTemplate', args=args)
 
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_create_by_router(self, confirm_mock):
+        confirm_mock.return_value = True
+
+        result = self.run_command(['vs', 'create',
+                                   '--cpu=2',
+                                   '--domain=example.com',
+                                   '--hostname=host',
+                                   '--os=UBUNTU_LATEST',
+                                   '--memory=1',
+                                   '--billing=hourly',
+                                   '--datacenter=dal05',
+                                   '--router-private=577940',
+                                   '--router-public=1639255',
+                                   '--tag=dev',
+                                   '--tag=green'])
+
+        self.assert_no_fail(result)
+        self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
+        args = ({
+            'startCpus': 2,
+            'maxMemory': 1024,
+            'hostname': 'host',
+            'domain': 'example.com',
+            'localDiskFlag': True,
+            'hourlyBillingFlag': True,
+            'supplementalCreateObjectOptions': {'bootMode': None},
+            'operatingSystemReferenceCode': 'UBUNTU_LATEST',
+            'datacenter': {'name': 'dal05'},
+            'primaryBackendNetworkComponent': {
+                        'router': {
+                            'id': 577940
+                        }
+            },
+            'primaryNetworkComponent': {
+                'router': {
+                    'id': 1639255
+                }
+            }
+        },)
+
+        self.assert_called_with('SoftLayer_Virtual_Guest', 'generateOrderTemplate', args=args)
+
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_create_with_wait_ready(self, confirm_mock):
         mock = self.set_mock('SoftLayer_Virtual_Guest', 'getObject')
@@ -485,6 +529,48 @@ class VirtCreateTests(testing.TestCase):
                  'networkComponents': [{'maxSpeed': 100}]},)
         self.assert_called_with('SoftLayer_Virtual_Guest', 'generateOrderTemplate', args=args)
 
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_create_like_transient(self, confirm_mock):
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getObject')
+        mock.return_value = {
+            'hostname': 'vs-test-like',
+            'domain': 'test.sftlyr.ws',
+            'datacenter': {'name': 'dal05'},
+            'networkComponents': [{'maxSpeed': 100}],
+            'dedicatedAccountHostOnlyFlag': False,
+            'privateNetworkOnlyFlag': False,
+            'billingItem': {'orderItem': {'preset': {'keyName': 'B1_1X2X25'}}},
+            'operatingSystem': {'softwareLicense': {
+                'softwareDescription': {'referenceCode': 'UBUNTU_LATEST'}
+            }},
+            'hourlyBillingFlag': True,
+            'localDiskFlag': False,
+            'transientGuestFlag': True,
+            'userData': {}
+        }
+
+        confirm_mock.return_value = True
+        result = self.run_command(['vs', 'create', '--like=123'])
+
+        self.assert_no_fail(result)
+        self.assertIn('"guid": "1a2b3c-1701"', result.output)
+        self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
+
+        args = ({'datacenter': {'name': 'dal05'},
+                 'domain': 'test.sftlyr.ws',
+                 'hourlyBillingFlag': True,
+                 'hostname': 'vs-test-like',
+                 'startCpus': None,
+                 'maxMemory': None,
+                 'localDiskFlag': None,
+                 'transientGuestFlag': True,
+                 'supplementalCreateObjectOptions': {
+                     'bootMode': None,
+                     'flavorKeyName': 'B1_1X2X25'},
+                 'operatingSystemReferenceCode': 'UBUNTU_LATEST',
+                 'networkComponents': [{'maxSpeed': 100}]},)
+        self.assert_called_with('SoftLayer_Virtual_Guest', 'generateOrderTemplate', args=args)
+
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_create_vs_test(self, confirm_mock):
         confirm_mock.return_value = True
@@ -511,9 +597,39 @@ class VirtCreateTests(testing.TestCase):
         result = self.run_command(['vs', 'create', '--hostname', 'TEST',
                                    '--domain', 'TESTING', '--cpu', '1',
                                    '--memory', '2034MB', '--flavor',
-                                   'UBUNTU', '--datacenter', 'TEST00'])
+                                   'B1_2X8X25', '--datacenter', 'TEST00'])
 
-        self.assertEqual(result.exit_code, 2)
+        self.assertEqual(2, result.exit_code)
+
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_create_vs_transient(self, confirm_mock):
+        confirm_mock.return_value = True
+
+        result = self.run_command(['vs', 'create', '--hostname', 'TEST',
+                                   '--domain', 'TESTING', '--flavor',
+                                   'B1_2X8X25', '--datacenter', 'TEST00',
+                                   '--transient', '--os', 'UBUNTU_LATEST'])
+
+        self.assert_no_fail(result)
+        self.assertEqual(0, result.exit_code)
+
+    def test_create_vs_bad_transient_monthly(self):
+        result = self.run_command(['vs', 'create', '--hostname', 'TEST',
+                                   '--domain', 'TESTING', '--flavor',
+                                   'B1_2X8X25', '--datacenter', 'TEST00',
+                                   '--transient', '--billing', 'monthly',
+                                   '--os', 'UBUNTU_LATEST'])
+
+        self.assertEqual(2, result.exit_code)
+
+    def test_create_vs_bad_transient_dedicated(self):
+        result = self.run_command(['vs', 'create', '--hostname', 'TEST',
+                                   '--domain', 'TESTING', '--flavor',
+                                   'B1_2X8X25', '--datacenter', 'TEST00',
+                                   '--transient', '--dedicated',
+                                   '--os', 'UBUNTU_LATEST'])
+
+        self.assertEqual(2, result.exit_code)
 
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_create_with_ipv6(self, confirm_mock):
@@ -567,6 +683,9 @@ class VirtCreateTests(testing.TestCase):
         Since its hard to test if the price ids gets added to placeOrder call,
         this test juse makes sure that code block isn't being skipped
         """
+        confirm_mock.return_value = True
+        amock = self.set_mock('SoftLayer_Product_Package', 'getItems')
+        amock.return_value = SoftLayer_Product_Package.getItemsVS
         result = self.run_command(['vs', 'create', '--test', '--hostname', 'TEST',
                                    '--domain', 'TESTING', '--flavor', 'B1_2X8X25',
                                    '--datacenter', 'TEST00', '--os', 'UBUNTU_LATEST',
@@ -591,8 +710,7 @@ class VirtCreateTests(testing.TestCase):
                                        '--domain', 'TESTING', '--flavor', 'B1_2X8X25',
                                        '--datacenter', 'TEST00', '--os', 'UBUNTU_LATEST'])
             self.assert_no_fail(result)
-            self.assertTrue('Successfully exported options to a template file.'
-                            in result.output)
+            self.assertIn('Successfully exported options to a template file.', result.output)
             contents = config_file.read().decode("utf-8")
             self.assertIn('hostname=TEST', contents)
             self.assertIn('flavor=B1_2X8X25', contents)
@@ -604,12 +722,12 @@ class VirtCreateTests(testing.TestCase):
                                    '--userdata', 'This is my user data ok'])
         self.assert_no_fail(result)
         expected_guest = [
-                {
-                    'domain': 'test.local',
-                    'hostname': 'test',
-                    'userData': [{'value': 'This is my user data ok'}]
-                }
-            ]
+            {
+                'domain': 'test.local',
+                'hostname': 'test',
+                'userData': [{'value': 'This is my user data ok'}]
+            }
+        ]
         # Returns a list of API calls that hit SL_Product_Order::placeOrder
         api_call = self.calls('SoftLayer_Product_Order', 'placeOrder')
         # Doing this because the placeOrder args are huge and mostly not needed to test
